@@ -25,8 +25,8 @@ def convert_ms(infile, outfile=None, ddi=None, compressor=None, chunk_shape=(100
         Input MS filename
     outfile : str
         Output zarr filename. If None, will use infile name with .vis.zarr extension
-    ddi : int
-        Specific ddi to convert. Leave as None to convert entire MS
+    ddi : int or string
+        Specific DDI to convert. DDI's are integer values, or use 'global' string for metadata table. Leave as None to convert entire MS
     compressor : numcodecs.blosc.Blosc
         The blosc compressor to use when saving the converted data to disk using zarr.
         If None the zstd compression algorithm used with compression level 2.
@@ -78,10 +78,7 @@ def convert_ms(infile, outfile=None, ddi=None, compressor=None, chunk_shape=(100
         MS.open(infile, nomodify=True, lockoptions={'option': 'usernoread'})
         ddis = MS.taql('select distinct DATA_DESC_ID from %s' % prefix + '.ms').getcol('DATA_DESC_ID')
         MS.close()
-
-    if compressor is None:
-        compressor = Blosc(cname='zstd', clevel=2, shuffle=0)
-
+    
     # initialize list of xarray datasets to be returned by this function
     xds_list = []
 
@@ -110,6 +107,7 @@ def convert_ms(infile, outfile=None, ddi=None, compressor=None, chunk_shape=(100
     tables = ['DATA_DESCRIPTION', 'SPECTRAL_WINDOW', 'POLARIZATION', 'SORTED_TABLE']  # initialize to things we don't want to process now
     ms_meta = tb()
 
+    
     ## ANTENNA table
     tables += ['ANTENNA']
     print('processing support table %s' % tables[-1], end='\r')
@@ -140,27 +138,36 @@ def convert_ms(infile, outfile=None, ddi=None, compressor=None, chunk_shape=(100
                 if not ms_meta.iscelldefined(col, 0): continue
                 if col in ['SPECTRAL_WINDOW_ID', 'ANTENNA_ID', 'FEED_ID']: continue
                 if ms_meta.isvarcol(col):
-                    tshape, tdim = (len(mcoords['receptors']),), ('receptors',)
-                    if col == 'BEAM_OFFSET':
-                        tshape, tdim = (2, len(mcoords['receptors'])), ('d2', 'receptors')
-                    elif col == 'POL_RESPONSE':
-                        tshape, tdim = (len(mcoords['receptors']), len(mcoords['receptors'])), ('receptors', 'receptors')
-                    data = ms_meta.getvarcol(col)
-                    data = np.array([apad(data['r' + str(kk)][..., 0], tshape) for kk in np.arange(len(data)) + 1])
-                    metadata = np.full((len(mcoords['spw']), len(mcoords['antenna']), len(mcoords['feed'])) + tshape, np.nan, dtype=data.dtype)
-                    metadata[spwidx, antidx, feedidx] = data
-                    mvars['FEED_' + col] = xarray.DataArray(metadata, dims=['spw', 'antenna', 'feed'] + list(tdim))
+                    try:
+                        tshape, tdim = (len(mcoords['receptors']),), ('receptors',)
+                        if col == 'BEAM_OFFSET':
+                            tshape, tdim = (2, len(mcoords['receptors'])), ('d2', 'receptors')
+                        elif col == 'POL_RESPONSE':
+                            tshape, tdim = (len(mcoords['receptors']), len(mcoords['receptors'])), ('receptors', 'receptors')
+                        data = ms_meta.getvarcol(col)
+                        data = np.array([apad(data['r' + str(kk)][..., 0], tshape) for kk in np.arange(len(data)) + 1])
+                        metadata = np.full((len(mcoords['spw']), len(mcoords['antenna']), len(mcoords['feed'])) + tshape, np.nan, dtype=data.dtype)
+                        metadata[spwidx, antidx, feedidx] = data
+                        mvars['FEED_' + col] = xarray.DataArray(metadata, dims=['spw', 'antenna', 'feed'] + list(tdim))
+                    except Exception:
+                        print('WARNING : unable to process col %s of table %s' % (col, tables[-1]))
                 else:
                     data = ms_meta.getcol(col).transpose()
                     if col == 'TIME': data = convert_time(data)
                     if data.ndim == 1:
-                        metadata = np.full((len(mcoords['spw']), len(mcoords['antenna']), len(mcoords['feed'])), np.nan, dtype=data.dtype)
-                        metadata[spwidx, antidx, feedidx] = data
-                        mvars['FEED_' + col] = xarray.DataArray(metadata, dims=['spw', 'antenna', 'feed'])
+                        try:
+                            metadata = np.full((len(mcoords['spw']), len(mcoords['antenna']), len(mcoords['feed'])), np.nan, dtype=data.dtype)
+                            metadata[spwidx, antidx, feedidx] = data
+                            mvars['FEED_' + col] = xarray.DataArray(metadata, dims=['spw', 'antenna', 'feed'])
+                        except Exception:
+                            print('WARNING : unable to process col %s of table %s' % (col, tables[-1]))
                     else:  # only POSITION should trigger this
-                        metadata = np.full((len(mcoords['spw']), len(mcoords['antenna']), len(mcoords['feed']), data.shape[1]), np.nan, dtype=data.dtype)
-                        metadata[spwidx, antidx, feedidx] = data
-                        mvars['FEED_' + col] = xarray.DataArray(metadata, dims=['spw', 'antenna', 'feed', 'd' + str(data.shape[1])])
+                        try:
+                            metadata = np.full((len(mcoords['spw']), len(mcoords['antenna']), len(mcoords['feed']), data.shape[1]), np.nan, dtype=data.dtype)
+                            metadata[spwidx, antidx, feedidx] = data
+                            mvars['FEED_' + col] = xarray.DataArray(metadata, dims=['spw', 'antenna', 'feed', 'd' + str(data.shape[1])])
+                        except Exception:
+                            print('WARNING : unable to process col %s of table %s' % (col, tables[-1]))
         ms_meta.close()
 
     ## FIELD table
@@ -355,7 +362,7 @@ def convert_ms(infile, outfile=None, ddi=None, compressor=None, chunk_shape=(100
 
     xds_list += [mxds]  # first item returned is always the global metadata
     print('meta data processing time ', time.time() - start)
-
+    
 
     ####################################################################
     # process each selected DDI from the input MS, assume a fixed shape within the ddi (should always be true)
@@ -445,7 +452,7 @@ def convert_ms(infile, outfile=None, ddi=None, compressor=None, chunk_shape=(100
                 if not ms_ddi.iscelldefined(col, idx_range[0]): continue
 
                 data = ms_ddi.getcol(col, idx_range[0], len(idx_range)).transpose()
-
+                print('idx_range,', col, idx_range[0],len(idx_range), data.shape)
                 if col in 'UVW':  # n_row x 3 -> n_time x n_baseline x 3
                     fulldata = np.full((len(chunk), n_baseline, data.shape[1]), np.nan, dtype=data.dtype)
                     fulldata[time_idxs[idx_range] - chunk[0], baseline_idxs[idx_range], :] = data
@@ -468,6 +475,11 @@ def convert_ms(infile, outfile=None, ddi=None, compressor=None, chunk_shape=(100
                         fulldata = np.full((len(chunk), n_baseline), np.nan, dtype=data.dtype)
                         if col == 'FLAG_ROW':
                             fulldata = np.ones((len(chunk), n_baseline), dtype=data.dtype)
+                        
+                        print('col name',col)
+                        print('full datashape', fulldata.shape)
+                        print('data.shape',data.shape)
+                        print('full data subshape',fulldata[time_idxs[idx_range] - chunk[0], baseline_idxs[idx_range]].shape)
                         fulldata[time_idxs[idx_range] - chunk[0], baseline_idxs[idx_range]] = data
                         chunkdata[col] = xarray.DataArray(fulldata, dims=['time', 'baseline'])
 
